@@ -1,23 +1,23 @@
 //! @file a68g-mp.h
 //! @author J. Marcel van der Veer
-//
+//!
 //! @section Copyright
-//
-// This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2022 J. Marcel van der Veer <algol68g@xs4all.nl>.
-//
+//!
+//! This file is part of Algol68G - an Algol 68 compiler-interpreter.
+//! Copyright 2001-2023 J. Marcel van der Veer [algol68g@xs4all.nl].
+//!
 //! @section License
-//
-// This program is free software; you can redistribute it and/or modify it 
-// under the terms of the GNU General Public License as published by the 
-// Free Software Foundation; either version 3 of the License, or 
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful, but 
-// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
-// or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
-// more details. You should have received a copy of the GNU General Public 
-// License along with this program. If not, see <http://www.gnu.org/licenses/>.
+//!
+//! This program is free software; you can redistribute it and/or modify it 
+//! under the terms of the GNU General Public License as published by the 
+//! Free Software Foundation; either version 3 of the License, or 
+//! (at your option) any later version.
+//!
+//! This program is distributed in the hope that it will be useful, but 
+//! WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
+//! or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
+//! more details. You should have received a copy of the GNU General Public 
+//! License along with this program. If not, see [http://www.gnu.org/licenses/].
 
 #if !defined (__A68G_MP_H__)
 #define __A68G_MP_H__
@@ -26,6 +26,7 @@
 // digits. This is however sufficient for most practical MP applications.
 
 #define MP_MAX_DECIMALS 250
+#define MP_MAX_DIGITS (1 + MP_MAX_DECIMALS / LOG_MP_RADIX)
 
 #define MP_STATUS(z) ((z)[0])
 #define MP_EXPONENT(z) ((z)[1])
@@ -249,7 +250,6 @@ enum {MP_SQRT_PI, MP_PI, MP_LN_PI, MP_SQRT_TWO_PI, MP_TWO_PI, MP_HALF_PI, MP_180
 // External multi-precision procedures
 
 extern BOOL_T check_mp_int (MP_T *, MOID_T *);
-extern BOOL_T is_int_mp (NODE_T *p, MP_T *z, int digits);
 extern BOOL_T same_mp (NODE_T *, MP_T *, MP_T *, int);
 extern int long_mp_digits (void);
 extern INT_T mp_to_int (NODE_T *, MP_T *, int);
@@ -365,7 +365,7 @@ extern void lt_mp (NODE_T *, A68_BOOL *, MP_T *, MP_T *, int);
 extern void ne_mp (NODE_T *, A68_BOOL *, MP_T *, MP_T *, int);
 extern void raw_write_mp (char *, MP_T *, int);
 extern void set_long_mp_digits (int);
-extern void test_long_int_range (NODE_T *, MP_T *, MOID_T *);
+extern void test_mp_int_range (NODE_T *, MP_T *, MOID_T *);
 
 extern GPROC genie_infinity_mp;
 extern GPROC genie_minus_infinity_mp;
@@ -541,7 +541,7 @@ extern GPROC genie_ln_beta_mpfr;
 extern GPROC genie_beta_mpfr;
 extern GPROC genie_gamma_inc_mpfr;
 extern GPROC genie_gamma_inc_real_mpfr;
-extern GPROC genie_gamma_inc_real_16_mpfr;
+extern GPROC genie_gamma_inc_double_mpfr;
 extern GPROC genie_gamma_mpfr;
 extern GPROC genie_lngamma_mpfr;
 extern GPROC genie_mpfr_erfc_mp;
@@ -552,6 +552,10 @@ extern GPROC genie_mpfr_mp;
 extern size_t mpfr_digits (void);
 #endif
 
+#if (A68_LEVEL >= 3)
+extern GPROC genie_quad_mp;
+#endif
+
 #if (A68_LEVEL <= 2)
 extern int get_mp_bits_width (MOID_T *);
 extern int get_mp_bits_words (MOID_T *);
